# Guide

Welcome to the LaminDB guide! 👋

```{include} ../../README.md
:start-line: 6
:end-line: -1
```

```{toctree}
:maxdepth: 2
:hidden:
:caption: Basic data

setup
ingest
select
add-delete
schema
run
```

```{toctree}
:maxdepth: 2
:hidden:
:caption: Basic biology

knowledge
link-features
link-samples
```
